---
title: <span class="badge object-type-enum"></span> PreprocessorType
---
# <span class="badge object-type-enum"></span> PreprocessorType

Types of pre-processor available. Defined by the metric.

## Definition

```python
class PreprocessorType(enum.StrEnum):
    """
    Types of pre-processor available. Defined by the metric.
    """

    NONE = "none"
    RATE = "rate"
    DELTA = "delta"
```
